# Generated by Django 4.2.6 on 2023-10-31 12:03

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("evalu", "0016_customevaluationitem"),
    ]

    operations = [
        migrations.RemoveConstraint(
            model_name="evaluationitem",
            name="part_site_order_unique",
        ),
    ]
