# Generated by Django 3.2.8 on 2021-10-17 15:18

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('evalu', '0005_key_model'),
    ]

    operations = [
        migrations.RenameModel(
            old_name='EvaluationKeySet',
            new_name='EvaluationKeyPair',
        ),
        migrations.AddField(
            model_name='evaluationresult',
            name='group',
            field=models.ForeignKey(default=0, on_delete=django.db.models.deletion.CASCADE, to='evalu.evaluationgroup', verbose_name='Evaluation group'),
            preserve_default=False,
        ),
    ]
