# Generated by Django 5.1.1 on 2024-10-06 12:24

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('cursus', '0003_drop_site'),
        ('evalu', '0021_evaluationgroup_finished_evaluationgroup_finished_at'),
    ]

    operations = [
        migrations.AlterField(
            model_name='comparisonresult',
            name='subject',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='evalu_results', to='cursus.subject', verbose_name='Subject'),
        ),
    ]
