{# -*- engine:django -*- #}

{% extends "core/base_print.html" %}

{% load i18n static %}

{% block browser_title %}{% blocktrans %}Evaluation Results{% endblocktrans %}{% endblock %}
{% block page_title %}
  {% blocktrans %}
    Evaluation Results
  {% endblocktrans %}
{% endblock %}
{% block extra_head %}
  <script src="{% url "javascript-catalog" %}?locale={{ LANGUAGE_CODE }}" type="text/javascript"></script>
{% endblock %}
{% block content %}
  {{ results|json_script:"results-data" }}

  <h4>
    {% blocktrans with group=object.group_name person=object.registration.person %}
      Evaluation Results of {{ person }} for {{ group }}
    {% endblocktrans %}
  </h4>
  {% include "evalu/results/partial_pdf_group.html" with group=results.0.0 results=results.0.1 %}

  <script src="{% static "js/helper.js" %}"></script>
  <script src="{% static "chart.js/dist/chart.umd.js" %}"></script>
  <script>
      const themeColor = "{{ SITE_PREFERENCES.theme__primary }}";
      const themeSecondaryColor = "{{ SITE_PREFERENCES.theme__secondary }}";
  </script>
  <script src="{% static "js/evalu/results.js" %}"></script>
{% endblock %}
