{# -*- engine:django -*- #}

{% extends "core/base.html" %}

{% load i18n static material_form %}

{% block browser_title %}{% blocktrans %}Evaluation Results{% endblocktrans %}{% endblock %}
{% block no_page_title %}{% endblock %}
{% block content %}
  <form action="" method="post">
    {% csrf_token %}
    <div class="container">
      <div class="card">
        <div class="card-content">
          <div class="card-title">
            {% if as_pdf %}
              {% trans "Unlock evaluation results for PDF export" %}
            {% else %}
              {% trans "Unlock evaluation results" %}
            {% endif %}
          </div>
          {% if as_pdf %}
            <figure class="alert warning">
              <i class="material-icons left">warning</i>
              {% blocktrans %}
                To generate a PDF file with your results, we have to save the generated PDF file on the server
                to make it downloadable to you. So, for this short time period, the results are saved unencrypted on the
                server as PDF file.
              {% endblocktrans %}
            </figure>
          {% endif %}
          <figure class="alert primary">
            <i class="material-icons left">info</i>
            {% blocktrans %}
              Please enter the password you set at the registration for the evaluation:
            {% endblocktrans %}
          </figure>
          {% form form=form %}{% endform %}
        </div>
        <div class="card-action-light">
          <button type="submit" class="waves-effect waves-light btn green">
            <i class="material-icons left">lock_open</i>
            {% trans "Unlock results" %}
          </button>
        </div>
      </div>
    </div>
  </form>
{% endblock %}
