# Generated by Django 3.2.16 on 2022-12-26 10:59

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('evalu', '0011_evaluation_finished'),
    ]

    operations = [
        migrations.AddField(
            model_name='evaluationregistration',
            name='deleted',
            field=models.BooleanField(default=False, verbose_name='Data deleted'),
        ),
        migrations.AddField(
            model_name='evaluationregistration',
            name='deleted_at',
            field=models.DateTimeField(blank=True, null=True, verbose_name='Data deleted at'),
        ),
    ]
