{# -*- engine:django -*- #}

{% extends "core/base.html" %}
{% load i18n %}

{% block browser_title %}{% blocktrans %}Finish Evaluation{% endblocktrans %}{% endblock %}
{% block page_title %}{% blocktrans with person=object.registration.person group=object.group_name %}Finish Evaluation of
  {{ person }} by
  {{ group }}{% endblocktrans %}{% endblock %}
{% block content %}
  <a class="btn waves-effect waves-light" href="{% url "manage_evaluation_process" object.registration.id %}">
    <i class="material-icons left">chevron_left</i>
    {% trans "Back to list" %}
  </a>

  <figure class="alert warning">
    <i class="material-icons left">warning</i>
    <figcaption>
      {% trans "Do you really want to finish the evaluation for this group?" %}
    </figcaption>
    {% blocktrans %}
      With this function, you can stop the evaluation process for this group.
      After this form is submitted, you won't be able to unlock this evaluation for further students.
      You will have access to the results after submitting.
    {% endblocktrans %}
  </figure>

  <form action="" method="post">
    {% csrf_token %}
    <button type="submit" name="finish" class="btn waves-effect waves-light red">
      <i class="material-icons left">stop</i>
      {% trans "Yes, I want" %}
    </button>

    <a class="btn secondary-color waves-effect waves-light" href="{% url "evaluation_phases_overview" %}">
      <i class="material-icons left">chevron_left</i>
      {% trans "No, back to list" %}
    </a>
  </form>


{% endblock %}
