# Generated by Django 3.2.7 on 2021-10-08 19:11

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('evalu', '0003_question_no_rich_text'),
    ]

    operations = [
        migrations.AddField(
            model_name='evaluationregistration',
            name='delete_after_phase',
            field=models.BooleanField(default=False, verbose_name='Delete evaluation data after this phase?'),
        ),
        migrations.AddField(
            model_name='evaluationregistration',
            name='privacy_form',
            field=models.FileField(blank=True, null=True, upload_to='', verbose_name='Submitted privacy form as PDF'),
        ),
        migrations.AlterField(
            model_name='evaluationregistration',
            name='phase',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='registrations', to='evalu.evaluationphase', verbose_name='Evaluation phase'),
        ),
    ]
