# Generated by Django 4.2.6 on 2023-10-09 14:12

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ("evalu", "0012_deletion"),
    ]

    operations = [
        migrations.RemoveField(
            model_name="evaluationphase",
            name="results_date_start",
        ),
    ]
