# Generated by Django 3.2.11 on 2022-01-22 16:34

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('evalu', '0010_evaluationresult_result_key'),
    ]

    operations = [
        migrations.AddField(
            model_name='evaluationregistration',
            name='finished',
            field=models.BooleanField(default=False, verbose_name='Finished'),
        ),
        migrations.AddField(
            model_name='evaluationregistration',
            name='finished_at',
            field=models.DateTimeField(blank=True, null=True, verbose_name='Finished at'),
        ),
    ]
