.steps {
  display: flex;
  justify-content: center;
  margin-bottom: 20px;
}

.steps .breadcrumb,
.steps .breadcrumb:last-child,
.steps .breadcrumb .material-icons {
  color: grey;
}

.steps .breadcrumb div {
  display: flex;
  justify-content: center;
  flex-direction: column;
}

.steps .breadcrumb .material-icons {
  margin-right: 0;
}

.steps .breadcrumb::before {
  display: none;
}

.steps .bread-icon {
  font-size: 25px;
  color: grey;
  line-height: 1.5;
  margin-right: 10px;
  margin-left: 10px;
}

@media only screen and (max-width: 600px) {
  .container {
    width: 100%;
  }
}

.agreement-widget {
  margin-bottom: 20px !important;
}

.agreement-widget .col {
  margin-bottom: 20px;
}

.agreement-widget .radio-container {
  display: flex;
  justify-content: space-around;
  flex-direction: row;
}

.agreement-widget .radio {
  display: flex;
  justify-content: center;
  flex-direction: column;
  align-items: center;
}

.agreement-widget [type="radio"]:not(:checked) + span,
.agreement-widget [type="radio"]:checked + span {
  padding-left: 25px;
}

.agreement-top-label {
  color: black;
  font-size: 12pt;
  line-height: 16pt;
  margin-bottom: 10px;
}
