# Generated by Django 4.2.6 on 2023-11-03 19:07

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("evalu", "0017_remove_evaluationitem_part_site_order_unique"),
    ]

    operations = [
        migrations.AddField(
            model_name="evaluationpart",
            name="optional",
            field=models.BooleanField(
                default=False,
                help_text="Students won't have to answer this part.",
                verbose_name="Optional part",
            ),
        ),
    ]
