# Generated by Django 3.2.9 on 2022-01-04 12:48

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('evalu', '0009_auto_20211206_1448'),
    ]

    operations = [
        migrations.AddField(
            model_name='evaluationresult',
            name='result_key',
            field=models.TextField(default='', verbose_name='Encrypted fernet key'),
            preserve_default=False,
        ),
    ]
