# Generated by Django 3.2.7 on 2021-10-12 13:14

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('evalu', '0004_privacy_form'),
    ]

    operations = [
        migrations.CreateModel(
            name='EvaluationKeySet',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('private_key', models.TextField(editable=False, verbose_name='Private key')),
                ('public_key', models.TextField(editable=False, verbose_name='Public key')),
            ],
            options={
                'verbose_name': 'Evaluation key set',
                'verbose_name_plural': 'Evaluation key set',
            },
        ),
        migrations.RemoveField(
            model_name='evaluationregistration',
            name='gpg_keys',
        ),
        migrations.AddField(
            model_name='evaluationregistration',
            name='keys',
            field=models.ForeignKey(default=0, editable=False, on_delete=django.db.models.deletion.CASCADE, to='evalu.evaluationkeyset', verbose_name='Keys used to encrypt the evaluation'),
            preserve_default=False,
        ),
    ]
