# Generated by Django 4.2.6 on 2023-10-23 19:03

import aleksis.core.managers
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ("evalu", "0015_migrate_evaluationitem_poly"),
    ]

    operations = [
        migrations.CreateModel(
            name="CustomEvaluationItem",
            fields=[
                (
                    "evaluationitem_ptr",
                    models.OneToOneField(
                        auto_created=True,
                        on_delete=django.db.models.deletion.CASCADE,
                        parent_link=True,
                        primary_key=True,
                        serialize=False,
                        to="evalu.evaluationitem",
                    ),
                ),
                (
                    "group",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        related_name="custom_items",
                        to="evalu.evaluationgroup",
                        verbose_name="Evaluation group",
                    ),
                ),
            ],
            options={
                "verbose_name": "Custom Evaluation Item",
                "verbose_name_plural": "Custom Evaluation Items",
            },
            bases=("evalu.evaluationitem",),
        ),
    ]
