# Generated by Django 5.1.1 on 2024-09-20 10:52

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('core', '0065_calendarevent_update_timezone_constraints'),
        ('evalu', '0019_drop_sites_add_managed_by'),
    ]

    operations = [
        migrations.AddField(
            model_name='evaluationphase',
            name='evaluation_group_types',
            field=models.ManyToManyField(blank=True, null=True, to='core.grouptype', verbose_name='Groups with these types can evaluate persons'),
        ),
    ]
