{# -*- engine:django -*- #}

{% extends "core/base.html" %}
{% load material_form i18n %}

{% block browser_title %}{% blocktrans %}Create Evaluation Part{% endblocktrans %}{% endblock %}
{% block page_title %}{% blocktrans %}Create Evaluation Part{% endblocktrans %}{% endblock %}

{% block content %}
  <form method="post">
    {% csrf_token %}
    {% form form=form %}{% endform %}
    {% include "core/partials/save_button.html" %}
  </form>
{% endblock %}
