# Generated by Django 3.2.6 on 2021-09-15 16:09

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('evalu', '0002_evaluation_item'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='evaluationitem',
            options={'verbose_name': 'Evaluation item', 'verbose_name_plural': 'Evaluation items'},
        ),
        migrations.AlterField(
            model_name='evaluationitem',
            name='question',
            field=models.TextField(help_text='as shown on evaluation form', verbose_name='Question'),
        ),
    ]
