# Generated by Django 3.2.9 on 2021-12-06 13:48

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('core', '0020_pdf_file_person_optional'),
        ('evalu', '0008_comparison_group'),
    ]

    operations = [
        migrations.AlterModelManagers(
            name='evaluationgroup',
            managers=[
            ],
        ),
        migrations.AlterField(
            model_name='comparisongroup',
            name='groups',
            field=models.ManyToManyField(related_name='evalu_comparison_groups', to='core.Group', verbose_name='Groups'),
        ),
        migrations.CreateModel(
            name='DoneEvaluationComparison',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('extended_data', models.JSONField(default=dict, editable=False)),
                ('comparison_group', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='done_evaluations_comparison', to='evalu.comparisongroup', verbose_name='Comparison group')),
                ('evaluation_group', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='done_evaluations_comparison', to='evalu.evaluationgroup', verbose_name='Evaluation group')),
            ],
            options={
                'verbose_name': 'Done evaluation (comparison)',
                'verbose_name_plural': 'Done evaluations (comparison)',
            },
        ),
    ]
